==> qbs-src-1.8.1.zip: qbs-src-1.8.1/src/lib/corelib/language/preparescriptobserver.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/
#ifndef QBS_PREPARESCRIPTOBSERVER_H
#define QBS_PREPARESCRIPTOBSERVER_H

#include "scriptpropertyobserver.h"

namespace qbs {
namespace Internal {
class ScriptEngine;

class PrepareScriptObserver : public ScriptPropertyObserver
{
public:
    PrepareScriptObserver(ScriptEngine *engine);

    void setProductObjectId(qint64 productId) { m_productObjectId = productId; }
    void setProjectObjectId(qint64 projectId) { m_projectObjectId = projectId; }

private:
    void onPropertyRead(const QScriptValue &object, const QString &name, const QScriptValue &value);

    ScriptEngine * const m_engine;
    qint64 m_productObjectId;
    qint64 m_projectObjectId;
};

} // namespace Internal
} // namespace qbs

#endif // Include guard.

==> qbs-src-1.11.1.zip: qbs-src-1.11.1/src/lib/corelib/language/preparescriptobserver.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qbs.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 3 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL3 included in the
** packaging of this file. Please review the following information to
** ensure the GNU Lesser General Public License version 3 requirements
** will be met: https://www.gnu.org/licenses/lgpl-3.0.html.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 2.0 or (at your option) the GNU General
** Public license version 3 or any later version approved by the KDE Free
** Qt Foundation. The licenses are as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL2 and LICENSE.GPL3
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-2.0.html and
** https://www.gnu.org/licenses/gpl-3.0.html.
**
** $QT_END_LICENSE$
**
****************************************************************************/
#ifndef QBS_PREPARESCRIPTOBSERVER_H
#define QBS_PREPARESCRIPTOBSERVER_H

#include "qualifiedid.h"
#include "scriptpropertyobserver.h"

#include <tools/set.h>

#include <QString>

#include <unordered_map>

namespace qbs {
namespace Internal {
class ScriptEngine;

class PrepareScriptObserver : public ScriptPropertyObserver
{
public:
    PrepareScriptObserver(ScriptEngine *engine, UnobserveMode unobserveMode);

    void setProductObjectId(qint64 productId) { m_productObjectId = productId; }
    void setProjectObjectId(qint64 projectId) { m_projectObjectId = projectId; }
    bool addImportId(qint64 importId) { return m_importIds.insert(importId).second; }
    void clearImportIds() { m_importIds.clear(); }
    void addParameterObjectId(qint64 id, const QString &depName, const QualifiedId &moduleName)
    {
        m_parameterObjects.insert(std::make_pair(id, depName + QLatin1Char(':')
                                                 + moduleName.toString()));
    }

private:
    void onPropertyRead(const QScriptValue &object, const QString &name, const QScriptValue &value);

    qint64 m_productObjectId;
    qint64 m_projectObjectId;
    std::unordered_map<qint64, QString> m_parameterObjects;
    Set<qint64> m_importIds;
};

} // namespace Internal
} // namespace qbs

#endif // Include guard.
